import { log } from "console";
import { randomBytes } from "crypto";

/**
 * Template string type for AUIDs
 */
export type AUID = `${string}-${string}-${string}-${string}`;

/**
 * Generates a crytografically strong AUID
 * 
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
export function generateAUID(): AUID {
    return [...Array(4)].map(() => 
        randomBytes(8).toString('hex') // Generates 16 hex characters (8 bytes * 2 hex chars per byte)
    ).join('-') as AUID;
};

/**
 * Fullproof regex for AUIDs
 */
export const isAUID = new RegExp(/^[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}$/);
